@@ -7,7 +7,7 @@ Attean::API::Model - RDF Model
 
 =head1 VERSION
 
-This document describes Attean::API::Model version 0.018
+This document describes Attean::API::Model version 0.019
 
 =head1 DESCRIPTION
 
@@ -46,6 +46,13 @@ L<Attean::API::QuadIterator>.
 Returns the number of quads in the model matching the supplied pattern
 (using the same matching semantics as C<< get_quads >>).
 
+=item C<< count_quads_estimate( $subject, $predicate, $object, $graph ) >>
+
+Returns an estimate of the number of quads in the model matching the supplied
+pattern (using the same matching semantics as C<< get_quads >>). This estimate
+is guaranteed to non-zero if the count returned from an equivalent call to
+`count_quads` would return a non-zero result.
+
 =item C<< get_graphs >>
 
 Returns an L<Attean::API::Iterator> of distinct L<Attean::API::Term> objects
@@ -115,7 +122,7 @@ subjects and objects present in the specified C<< $graph >>.
 
 use Attean::API::Binding;
 
-package Attean::API::Model 0.018 {
+package Attean::API::Model 0.019 {
 	use Sub::Install;
 	use Sub::Util qw(set_subname);
 	use URI::Namespace;
@@ -151,6 +158,7 @@ package Attean::API::Model 0.018 {
 	}
 	
 	requires 'count_quads';
+	requires 'count_quads_estimate';
 	requires 'get_graphs';
 	
 	sub get_list {
@@ -236,7 +244,7 @@ package Attean::API::Model 0.018 {
 }
 
 
-package Attean::API::MutableModel 0.018 {
+package Attean::API::MutableModel 0.019 {
 	use Attean::RDF;
 	use LWP::UserAgent;
 	use Encode qw(encode);
@@ -328,21 +336,21 @@ package Attean::API::MutableModel 0.018 {
 }
 
 
-package Attean::API::ETagCacheableModel 0.018 {
+package Attean::API::ETagCacheableModel 0.019 {
 	use Moo::Role;
 	
 	requires 'etag_value_for_quads';
 }
 
 
-package Attean::API::TimeCacheableModel 0.018 {
+package Attean::API::TimeCacheableModel 0.019 {
 	use Moo::Role;
 	
 	requires 'mtime_for_quads';
 }
 
 
-package Attean::API::BulkUpdatableModel 0.018 {
+package Attean::API::BulkUpdatableModel 0.019 {
 	use Moo::Role;
 	
 	with 'Attean::API::MutableModel';
@@ -359,7 +367,7 @@ package Attean::API::BulkUpdatableModel 0.018 {
 	};
 
 	# End bulk updates the moment a read operation is performed...
-	before [qw(get_quads get_bindings count_quads get_graphs subject predicate object graph)] => sub {
+	before [qw(get_quads get_bindings count_quads count_quads_estimate get_graphs subject predicate object graph)] => sub {
 		my $self	= shift;
 		$self->end_bulk_updates();
 	};
@@ -379,7 +387,7 @@ at L<https://github.com/kasei/attean/issues>.
 
 =head1 SEE ALSO
 
-L<http://www.perlrdf.org/>
+
 
 =head1 AUTHOR
 
